@@ -1,5 +1,6 @@
 from collections import OrderedDict
 from collections import abc
+from typing import List
 
 
 class Container(abc.MutableMapping):
@@ -23,6 +24,8 @@ class Container(abc.MutableMapping):
     return len(self._keys)
 
   def __getitem__(self, x):
+    if isinstance(x, str):
+      return getattr(self, x)
     if isinstance(x, int):
       k = self._keys[x]
       return getattr(self, k)
@@ -33,6 +36,8 @@ class Container(abc.MutableMapping):
   def __setitem__(self, key, value):
     if isinstance(key, int):
       setattr(self, self._keys[key], value)
+    elif isinstance(key, str):
+      setattr(self, key, value)
 
   def __delitem__(self, key):
     pass
@@ -57,3 +62,42 @@ class Samples:
 
   def __iter__(self):
     return (*self.inputs, *self.targets)
+
+
+class Batch:
+  inputs: Inputs
+  targets: Targets
+
+  def __init__(self, inputs, targets, outputs=None):
+    self.inputs = inputs
+    self.targets = targets
+
+  def __iter__(self):
+    return (*self.inputs, *self.targets)
+
+  def to(self, device):
+    pass
+
+  @property
+  def size(self):
+    return len(self.inputs[0])
+
+
+  def items(self):
+    return []
+
+class DetectionBatch(Batch):
+  boxes: Inputs
+
+class SegmentationBatch(Batch):
+  masks: Inputs
+
+
+batches: List[Batch] = []
+for b in batches:
+  b.to(model.device)
+  inputs, targets = b
+
+  outputs = model(*inputs)
+  b.outputs = outputs
+
